==> jc-1.4.0.tar.gz: gnu/java/nio/PipeImpl.h <==
// class gnu.java.nio.PipeImpl

// class file dependencies
// @dep_class 69e22b3bfcf0149b gnu_java_nio_PipeImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2951d2f8b8defcbd java_nio_channels_Pipe

// header file dependencies
// @dep_header java_nio_channels_Pipe

#include "java/nio/channels/Pipe.h"

#ifndef _JC_gnu_java_nio_PipeImpl_H_
#define _JC_gnu_java_nio_PipeImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object;
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_Pipe__24SinkChannel$object;
struct _jc_java_nio_channels_Pipe__24SourceChannel$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_PipeImpl$sub_refs	_jc_gnu_java_nio_PipeImpl$sub_refs;
typedef struct _jc_gnu_java_nio_PipeImpl$sub_nonrefs	_jc_gnu_java_nio_PipeImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl$refs	_jc_gnu_java_nio_PipeImpl$refs;
typedef struct _jc_gnu_java_nio_PipeImpl$nonrefs	_jc_gnu_java_nio_PipeImpl$nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl$object	_jc_gnu_java_nio_PipeImpl$object;

typedef const struct _jc_gnu_java_nio_PipeImpl$vmethods	_jc_gnu_java_nio_PipeImpl$vmethods;
typedef const struct _jc_gnu_java_nio_PipeImpl$vtable	_jc_gnu_java_nio_PipeImpl$vtable;
typedef const struct _jc_gnu_java_nio_PipeImpl$vtype	_jc_gnu_java_nio_PipeImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_PipeImpl$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual methods
extern struct _jc_java_nio_channels_Pipe__24SinkChannel$object *_jc_gnu_java_nio_PipeImpl$method$sink$a72af214bdd8aa6e(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *);
extern struct _jc_java_nio_channels_Pipe__24SourceChannel$object *_jc_gnu_java_nio_PipeImpl$method$source$025193fa1d7529c6(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_PipeImpl$method_info$sink$a72af214bdd8aa6e;
extern _jc_method _jc_gnu_java_nio_PipeImpl$method_info$source$025193fa1d7529c6;

// Virtual methods structure
struct _jc_gnu_java_nio_PipeImpl$vmethods {
	struct _jc_java_nio_channels_Pipe__24SinkChannel$object	*(*sink$a72af214bdd8aa6e)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *);
	struct _jc_java_nio_channels_Pipe__24SourceChannel$object	*(*source$025193fa1d7529c6)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *);
};

// Vtable
struct _jc_gnu_java_nio_PipeImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_Pipe$vmethods	java_nio_channels_Pipe;
	_jc_gnu_java_nio_PipeImpl$vmethods	gnu_java_nio_PipeImpl;
};

// Vtype
struct _jc_gnu_java_nio_PipeImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_PipeImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl$sub_refs {
	struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object	*sink;
	struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object	*source;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl$refs {
    _jc_gnu_java_nio_PipeImpl$sub_refs	gnu_java_nio_PipeImpl;
    _jc_java_nio_channels_Pipe$sub_refs	java_nio_channels_Pipe;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_Pipe$sub_nonrefs	java_nio_channels_Pipe;
    _jc_gnu_java_nio_PipeImpl$sub_nonrefs	gnu_java_nio_PipeImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_PipeImpl$object {
	_jc_gnu_java_nio_PipeImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_PipeImpl$vtype	*vtype;
	_jc_gnu_java_nio_PipeImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_PipeImpl$vtype _jc_gnu_java_nio_PipeImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_PipeImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_PipeImpl$class_object;

#endif	/* _JC_gnu_java_nio_PipeImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/PipeImpl.h <==
// class gnu.java.nio.PipeImpl

// class file dependencies
// @dep_class 69e22b3bfcf0149b gnu_java_nio_PipeImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2951d2f8b8defcbd java_nio_channels_Pipe

// header file dependencies
// @dep_header java_nio_channels_Pipe

#include "java/nio/channels/Pipe.h"

#ifndef _JC_gnu_java_nio_PipeImpl_H_
#define _JC_gnu_java_nio_PipeImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object;
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_Pipe__24SinkChannel$object;
struct _jc_java_nio_channels_Pipe__24SourceChannel$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_PipeImpl$sub_refs	_jc_gnu_java_nio_PipeImpl$sub_refs;
typedef struct _jc_gnu_java_nio_PipeImpl$sub_nonrefs	_jc_gnu_java_nio_PipeImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl$refs	_jc_gnu_java_nio_PipeImpl$refs;
typedef struct _jc_gnu_java_nio_PipeImpl$nonrefs	_jc_gnu_java_nio_PipeImpl$nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl$object	_jc_gnu_java_nio_PipeImpl$object;

typedef const struct _jc_gnu_java_nio_PipeImpl$vmethods	_jc_gnu_java_nio_PipeImpl$vmethods;
typedef const struct _jc_gnu_java_nio_PipeImpl$vtable	_jc_gnu_java_nio_PipeImpl$vtable;
typedef const struct _jc_gnu_java_nio_PipeImpl$vtype	_jc_gnu_java_nio_PipeImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_PipeImpl$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_Pipe__24SinkChannel$object *_jc_gnu_java_nio_PipeImpl$method$sink$a72af214bdd8aa6e(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_Pipe__24SourceChannel$object *_jc_gnu_java_nio_PipeImpl$method$source$025193fa1d7529c6(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_PipeImpl$method_info$sink$a72af214bdd8aa6e;
extern _jc_method _jc_gnu_java_nio_PipeImpl$method_info$source$025193fa1d7529c6;

// Virtual methods structure
struct _jc_gnu_java_nio_PipeImpl$vmethods {
	struct _jc_java_nio_channels_Pipe__24SinkChannel$object	*(*sink$a72af214bdd8aa6e)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_Pipe__24SourceChannel$object	*(*source$025193fa1d7529c6)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_PipeImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_Pipe$vmethods	java_nio_channels_Pipe;
	_jc_gnu_java_nio_PipeImpl$vmethods	gnu_java_nio_PipeImpl;
};

// Vtype
struct _jc_gnu_java_nio_PipeImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_PipeImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl$sub_refs {
	struct _jc_gnu_java_nio_PipeImpl__24SinkChannelImpl$object	*sink;
	struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object	*source;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl$refs {
    _jc_gnu_java_nio_PipeImpl$sub_refs	gnu_java_nio_PipeImpl;
    _jc_java_nio_channels_Pipe$sub_refs	java_nio_channels_Pipe;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_Pipe$sub_nonrefs	java_nio_channels_Pipe;
    _jc_gnu_java_nio_PipeImpl$sub_nonrefs	gnu_java_nio_PipeImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_PipeImpl$object {
	_jc_gnu_java_nio_PipeImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_PipeImpl$vtype	*vtype;
	_jc_gnu_java_nio_PipeImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_PipeImpl$vtype _jc_gnu_java_nio_PipeImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_PipeImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_PipeImpl$class_object;

#endif	/* _JC_gnu_java_nio_PipeImpl_H_ */
